package xyz.wbsite.dbtool.javafx.manger.callable;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import xyz.wbsite.dbtool.javafx.manger.FreeMarkerManager;
import xyz.wbsite.dbtool.javafx.manger.ManagerFactory;
import xyz.wbsite.dbtool.javafx.po.Doc;
import xyz.wbsite.dbtool.javafx.tool.Tool;

import javax.xml.parsers.DocumentBuilderFactory;
import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.concurrent.Callable;

public class DocCallable implements Callable {

    private File module;
    private File docFile;
    private List<Doc> ajaxDocList;
    private List<Doc> apiDocList;
    private Tool tool = new Tool();
    File docModule;
    private FreeMarkerManager freeMarkerManager;

    public DocCallable(File module, File docFile, List<Doc> docList) {
        this.module = module;
        this.docFile = docFile;
        this.ajaxDocList = docList;
        this.apiDocList = docList;
        this.freeMarkerManager = ManagerFactory.getFreeMarkerManager();
    }

    public Boolean call() throws Exception {
        if (!docFile.exists()) {
            docFile.mkdir();
        } else {
            Tool.clear(docFile);
        }

        String version = "1.0";

        File file = new File(module, "pom.xml");

        DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
        Document document = documentBuilderFactory.newDocumentBuilder().parse(file);

        Element documentElement = document.getDocumentElement();
        NodeList childNodes = documentElement.getChildNodes();
        for (int i = 0; i < childNodes.getLength(); i++) {
            Node item = childNodes.item(i);
            if (item.getNodeName().equals("version")) {
                version = item.getTextContent();
            }
        }

        List<Doc> ajaxList = new ArrayList<>();
        List<Doc> apiList = new ArrayList<>();
        for (Doc doc : ajaxDocList) {
            if (doc.isCheck()) {
                if ("ajax".equals(doc.getType().toLowerCase())) {
                    ajaxList.add(doc);
                }
                if ("api".equals(doc.getType().toLowerCase())) {
                    apiList.add(doc);
                }
            }
        }
        if (ajaxList.size() > 0) {
            File ajax = Tool.createFile(this.docFile, "index.html");
            HashMap<String, Object> ctx = new HashMap<String, Object>();
            ctx.put("ajaxList", ajaxList);
            freeMarkerManager.outputTemp(ajax, "Doc/data.json", ctx);
        }

        File js = Tool.createPath(this.docFile, "js");
        File css = Tool.createPath(this.docFile, "css");

        Tool.outputResource("Doc/js/index.js", Tool.createFile(js, "index.js"));
        Tool.outputResource("Doc/js/vue.min.js", Tool.createFile(js, "vue.min.js"));
        Tool.outputResource("Doc/css/index.css", Tool.createFile(css, "index.css"));
        Tool.outputResource("Doc/index.html", Tool.createFile(this.docFile, "index.html"));

        if (apiList.size() > 0) {
            File api = Tool.createFile(js, "index.js");
            HashMap<String, Object> ctx = new HashMap<String, Object>();
            ctx.put("apiList", apiList);
            freeMarkerManager.outputTemp(api, "Doc/js/index.js", ctx);
        }

        System.out.println("finish");
        return true;
    }

}
